---
title: <span class="badge object-type-scalar"></span> DecibelMilliWatt
---
# <span class="badge object-type-scalar"></span> DecibelMilliWatt

Energy: Decibel-milliwatt (dBm)

## Definition

```python
# Energy: Decibel-milliwatt (dBm)
DecibelMilliWatt: typing.Literal["dBm"] = "dBm"
```
